package ascon
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module Ascon.Xof128Source
The Ascon-XOF128 extendable-output function.
An immutable state that accepts more message bytes.
An immutable state that can only produce output.
Error returned when a requested byte length is invalid.
absorb state input returns a state containing input.
Finalizes absorption. Its result cannot be passed to absorb.
squeeze state ~length emits the next length bytes. Repeated calls concatenate to the same output as one longer call.
One-shot XOF output. length must be positive, as required by SP 800-232.